/*
 * libfeedback
 * Copyright (c) 2016 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#ifndef __FEEDBACK_IDS_INTERNAL_H__
#define __FEEDBACK_IDS_INTERNAL_H__

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @file feedback-ids-internal.h
 * @brief This file contains the feedback API
 */

/**
 * @addtogroup CAPI_FEEDBACK_MODULE
 * @{
 */

/**
 * @brief Enumerations of the system pre-defined patterns for feedback interface
 * @details
 * Each feedback pattern can have separate media files of each types.
 * But Depending on vendor design, pattern may not have any type of file.
 *
 */
typedef enum {
	FEEDBACK_PATTERN_INTERNAL_NONE = FEEDBACK_PATTERN_NONE,
	FEEDBACK_PATTERN_SIP_BACKSPACE          = 2,
	FEEDBACK_PATTERN_SIP_FUNCTION           = 3,
	FEEDBACK_PATTERN_SIP_FJKEY              = 4,
	FEEDBACK_PATTERN_MAX_CHARACTER          = 5,
	FEEDBACK_PATTERN_MULTI_TAP              = 20,

	FEEDBACK_PATTERN_MESSAGE_ON_CALL        = 24,    /**< feedback pattern when incoming a message on call */
	FEEDBACK_PATTERN_EMAIL_ON_CALL          = 26,    /**< feedback pattern when incoming an email on call */
	FEEDBACK_PATTERN_WAKEUP_ON_CALL         = 28,    /**< feedback pattern when alert wake up call on call */
	FEEDBACK_PATTERN_SCHEDULE_ON_CALL       = 30,    /**< feedback pattern when alert schedule alarm on call */
	FEEDBACK_PATTERN_TIMER_ON_CALL          = 32,    /**< feedback pattern when alert timer on call */
	FEEDBACK_PATTERN_GENERAL_ON_CALL        = 34,    /**< feedback pattern when alert general event on call */
	FEEDBACK_PATTERN_SMART_ALERT            = 35,
	FEEDBACK_PATTERN_CHARGERCONN_ON_CALL    = 39,    /**< feedback pattern when connecting charger on call */
	FEEDBACK_PATTERN_CHARGING_ERROR_ON_CALL = 41,    /**< feedback pattern when occuring charging error on call */
	FEEDBACK_PATTERN_FULLCHARGED_ON_CALL    = 43,    /**< feedback pattern when full charged on call */
	FEEDBACK_PATTERN_LOWBATT_ON_CALL        = 45,    /**< feedback pattern when low battery on call */
	FEEDBACK_PATTERN_LOCK_SWIPE             = 48,
	FEEDBACK_PATTERN_UNLOCK_SWIPE,
	FEEDBACK_PATTERN_GEOMETRIC_LOCK,
	FEEDBACK_PATTERN_CALLCONNECT,
	FEEDBACK_PATTERN_DISCALLCONNECT,
	FEEDBACK_PATTERN_OUTGOING_CALL          = 53,    /**< feedback pattern when connected outgoing call */
	FEEDBACK_PATTERN_MINUTEMINDER,
	FEEDBACK_PATTERN_BT_PAIRING             = 59,
	FEEDBACK_PATTERN_BT_WAITING,
	FEEDBACK_PATTERN_SCREEN_CAPTURE         = 61,    /**< feedback pattern when screen capture */

	FEEDBACK_PATTERN_UV_PROCESSING          = 95,
	FEEDBACK_PATTERN_SHEALTH_START,
	FEEDBACK_PATTERN_SHEALTH_PAUSE,
	FEEDBACK_PATTERN_SHEALTH_STOP,
	FEEDBACK_PATTERN_3RD_APPLICATION,
	FEEDBACK_PATTERN_TICK,
	FEEDBACK_PATTERN_TRANSITION_CIRCULAR,
	FEEDBACK_PATTERN_TRANSITION_POP,
	FEEDBACK_PATTERN_PROCESS,
	FEEDBACK_PATTERN_MOVE_LIST,
	FEEDBACK_PATTERN_DISMISS,
	FEEDBACK_PATTERN_CLOCK_SECOND_HAND,
	//SYSTEM_SHORT
	//SYSTEM_ERROR
	FEEDBACK_PATTERN_SPIRAL_DOWN            = 109,
	FEEDBACK_PATTERN_MOVE_LIST_2,
	FEEDBACK_PATTERN_SPIRAL_UP,
	//SYSTEM_LONG
	//SYSTEM_MID
	FEEDBACK_PATTERN_SILENCE                = 114,
	FEEDBACK_PATTERN_INACTIVE_TENSION,
	FEEDBACK_PATTERN_INACTIVE_FINE,
	//END_EFFECT
	FEEDBACK_PATTERN_SHEALTH_NOTICE         = 118,
	FEEDBACK_PATTERN_SHEALTH_GENTLE_ALERT,
	FEEDBACK_PATTERN_END_EFFECT_FINE,
	FEEDBACK_PATTERN_CLICK_VALUE,
	FEEDBACK_PATTERN_CLICK_FINE_TRAIN_1,
	FEEDBACK_PATTERN_CLICK_FINE,
	FEEDBACK_PATTERN_CLICK_SLIDER,
	FEEDBACK_PATTERN_CLICK_MEDIUM,
	FEEDBACK_PATTERN_CLICK_STRONG,
	FEEDBACK_PATTERN_TURN_RIGHT,
	FEEDBACK_PATTERN_TURN_LEFT,
	FEEDBACK_PATTERN_FUNCTION               = 129,
//	FEEDBACK_PATTERN_RINGER                 = 129,   /**< Feedback pattern for incoming call */
	FEEDBACK_PATTERN_VOICE_START,
	FEEDBACK_PATTERN_VOICE_STOP,
	FEEDBACK_PATTERN_COMMUNICATION,
	FEEDBACK_PATTERN_MESSAGE_STRONG_BUZZ,
	FEEDBACK_PATTERN_EMAIL_STRONG_BUZZ,
	//GENERAL_STRONG_BUZZ
	FEEDBACK_PATTERN_COMMUNICATION_STRONG_BUZZ = 136,
	FEEDBACK_PATTERN_SCHEDULE_STRONG_BUZZ,
	FEEDBACK_PATTERN_WAKEUP_STRONG_BUZZ,
	FEEDBACK_PATTERN_TIMER_STRONG_BUZZ,
	FEEDBACK_PATTERN_RINGER_STRONG_BUZZ,
	FEEDBACK_PATTERN_HEARTBEAT,
	FEEDBACK_PATTERN_HEARTBEAT_FAST,
	FEEDBACK_PATTERN_SETTING_ON,
	FEEDBACK_PATTERN_SETTING_OFF,
	FEEDBACK_PATTERN_CONNECT,
	FEEDBACK_PATTERN_DISCONNECT             = 146,
//	FEEDBACK_PATTERN_NOTIFICATION           = 146,	/**< Feedback pattern for notification */
	FEEDBACK_PATTERN_FIND_MY_GEAR,
	FEEDBACK_PATTERN_NOTIFICATION_1,
	FEEDBACK_PATTERN_NOTIFICATION_1_STRONG_BUZZ,
	FEEDBACK_PATTERN_NOTIFICATION_2,
	FEEDBACK_PATTERN_NOTIFICATION_2_STRONG_BUZZ,
	FEEDBACK_PATTERN_NOTIFICATION_3,
	FEEDBACK_PATTERN_NOTIFICATION_3_STRONG_BUZZ,
	FEEDBACK_PATTERN_NOTIFICATION_4,
	FEEDBACK_PATTERN_NOTIFICATION_4_STRONG_BUZZ,
	FEEDBACK_PATTERN_NOTIFICATION_5,
	FEEDBACK_PATTERN_NOTIFICATION_5_STRONG_BUZZ,
	FEEDBACK_PATTERN_NOTIFICATION_6,
	FEEDBACK_PATTERN_NOTIFICATION_6_STRONG_BUZZ,
	FEEDBACK_PATTERN_NOTIFICATION_7,
	FEEDBACK_PATTERN_NOTIFICATION_7_STRONG_BUZZ,
	FEEDBACK_PATTERN_NOTIFICATION_8,
	FEEDBACK_PATTERN_NOTIFICATION_8_STRONG_BUZZ,
	FEEDBACK_PATTERN_NOTIFICATION_9,
	FEEDBACK_PATTERN_NOTIFICATION_9_STRONG_BUZZ,
	FEEDBACK_PATTERN_NOTIFICATION_10,
	FEEDBACK_PATTERN_NOTIFICATION_10_STRONG_BUZZ,
	FEEDBACK_PATTERN_RING_1,
	FEEDBACK_PATTERN_RING_1_STRONG_BUZZ,
	FEEDBACK_PATTERN_RING_2,
	FEEDBACK_PATTERN_RING_2_STRONG_BUZZ,
	FEEDBACK_PATTERN_RING_3,
	FEEDBACK_PATTERN_RING_3_STRONG_BUZZ,
	FEEDBACK_PATTERN_RING_4,
	FEEDBACK_PATTERN_RING_4_STRONG_BUZZ,
	FEEDBACK_PATTERN_RING_5,
	FEEDBACK_PATTERN_RING_5_STRONG_BUZZ,
	FEEDBACK_PATTERN_RING_6,
	FEEDBACK_PATTERN_RING_6_STRONG_BUZZ,
	FEEDBACK_PATTERN_RING_7,
	FEEDBACK_PATTERN_RING_7_STRONG_BUZZ,
	FEEDBACK_PATTERN_RING_8,
	FEEDBACK_PATTERN_RING_8_STRONG_BUZZ,
	FEEDBACK_PATTERN_RING_9,
	FEEDBACK_PATTERN_RING_9_STRONG_BUZZ,
	FEEDBACK_PATTERN_RING_10,
	FEEDBACK_PATTERN_RING_10_STRONG_BUZZ,

	FEEDBACK_PATTERN_ALARM_1,
	FEEDBACK_PATTERN_ALARM_1_STRONG_BUZZ,
	FEEDBACK_PATTERN_ALARM_2,
	FEEDBACK_PATTERN_ALARM_2_STRONG_BUZZ,
	FEEDBACK_PATTERN_ALARM_3,
	FEEDBACK_PATTERN_ALARM_3_STRONG_BUZZ,
	FEEDBACK_PATTERN_ALARM_4,
	FEEDBACK_PATTERN_ALARM_4_STRONG_BUZZ,
	FEEDBACK_PATTERN_ALARM_5,
	FEEDBACK_PATTERN_ALARM_5_STRONG_BUZZ,
	FEEDBACK_PATTERN_ALARM_6,
	FEEDBACK_PATTERN_ALARM_6_STRONG_BUZZ,
	FEEDBACK_PATTERN_ALARM_7,
	FEEDBACK_PATTERN_ALARM_7_STRONG_BUZZ,
	FEEDBACK_PATTERN_ALARM_8,
	FEEDBACK_PATTERN_ALARM_8_STRONG_BUZZ,
	FEEDBACK_PATTERN_ALARM_9,
	FEEDBACK_PATTERN_ALARM_9_STRONG_BUZZ,
	FEEDBACK_PATTERN_ALARM_10,
	FEEDBACK_PATTERN_ALARM_10_STRONG_BUZZ,
	FEEDBACK_PATTERN_PICKER,
	FEEDBACK_PATTERN_PICKER_FINISH,
	FEEDBACK_PATTERN_ON_OFF_SWITCH,
	FEEDBACK_PATTERN_REORDER,
	FEEDBACK_PATTERN_CURSOR_MOVE,

	FEEDBACK_PATTERN_RESERVED_END           = 10000,
	// Add new pattern ids for Mobile and Wearable devices here
	// ...
	FEEDBACK_PATTERN_MMS = FEEDBACK_PATTERN_RESERVED_END,

	FEEDBACK_PATTERN_HOURLY_ALERT,
	FEEDBACK_PATTERN_SAFETY_ALERT,
	FEEDBACK_PATTERN_ACCIDENT_DETECT,
	FEEDBACK_PATTERN_SEND_SOS_MESSAGE,
	FEEDBACK_PATTERN_END_SOS_MESSAGE,
	FEEDBACK_PATTERN_EMERGENCY_BUZZER,
	FEEDBACK_PATTERN_SAFETY_LOW_POWER,
	FEEDBACK_PATTERN_CMAS,
	FEEDBACK_PATTERN_RINGER,
	FEEDBACK_PATTERN_NOTIFICATION,
	FEEDBACK_PATTERN_INFO,
	FEEDBACK_PATTERN_WARNING,
	FEEDBACK_PATTERN_ERROR,
	FEEDBACK_PATTERN_EMERGENCY,
	FEEDBACK_PATTERN_INTERNAL_WAKEUP,
	FEEDBACK_PATTERN_INTERNAL_TIMER,
	FEEDBACK_PATTERN_TEMPERATURE_WARNING,
	FEEDBACK_PATTERN_COOLDOWN_WARNING_1,
	FEEDBACK_PATTERN_COOLDOWN_WARNING_2,
	FEEDBACK_PATTERN_SPEED_UP,
	FEEDBACK_PATTERN_SLOW_DOWN,
	FEEDBACK_PATTERN_KEEP_THIS_PACE,
	FEEDBACK_PATTERN_GOAL_ACHIEVED,
	FEEDBACK_PATTERN_EXERCISE_COUNT,
	FEEDBACK_PATTERN_START_CUE,
	FEEDBACK_PATTERN_HEALTH_PACE,
	FEEDBACK_PATTERN_INACTIVE_TIME,
	FEEDBACK_PATTERN_CMAS_CA,
	FEEDBACK_PATTERN_NFC_SUCCESS,

	FEEDBACK_PATTERN_MEASURING_SUCCESS,
	FEEDBACK_PATTERN_MEASURING_FAILURE,
	FEEDBACK_PATTERN_MEDITATION, /**< Feedback pattern for meditation start/stop timer (Since 5.5) */
	FEEDBACK_PATTERN_MEDITATION_INTERVAL, /**< Feedback pattern for meditation interval (notification) (Since 5.5) */

	FEEDBACK_PATTERN_FALL_DETECTION_1,
	FEEDBACK_PATTERN_FALL_DETECTION_2,

	FEEDBACK_PATTERN_SMART_GESTURE,

	FEEDBACK_PATTERN_MOBILE_END             = 20000,
	// Add new pattern ids for TV devices here
	// ...
	FEEDBACK_PATTERN_TV_END                 = 30000,
	// Add new pattern ids for IoT devices here
	// ...
	FEEDBACK_PATTERN_IOT_END                = 40000,
	FEEDBACK_PATTERN_BASIC,
	FEEDBACK_PATTERN_TOGGLE_ON,
	FEEDBACK_PATTERN_TOGGLE_OFF,
	FEEDBACK_PATTERN_LONG_PRESS_ON,
	FEEDBACK_PATTERN_LONG_PRESS_OFF,
	FEEDBACK_PATTERN_INVALID,
	FEEDBACK_PATTERN_CONFIRM,
	FEEDBACK_PATTERN_POPUP,
	FEEDBACK_PATTERN_PREHEAT_ENDING,
	FEEDBACK_PATTERN_TASK_ENDING,
	FEEDBACK_PATTERN_SCROLL,
	FEEDBACK_PATTERN_PAGE_TURN,
	FEEDBACK_PATTERN_OP_START,
	FEEDBACK_PATTERN_OP_PAUSE,
	FEEDBACK_PATTERN_OP_STOP,
	FEEDBACK_PATTERN_DEFAULT,
	FEEDBACK_PATTERN_DEFAULT_LEVEL1,
	FEEDBACK_PATTERN_LEVEL1,
	FEEDBACK_PATTERN_LEVEL2,
	FEEDBACK_PATTERN_LEVEL3,
	FEEDBACK_PATTERN_LEVEL4,
	FEEDBACK_PATTERN_LEVEL5,
	FEEDBACK_PATTERN_LEVEL6,
	FEEDBACK_PATTERN_LEVEL7,
	FEEDBACK_PATTERN_LEVEL8,
	FEEDBACK_PATTERN_LEVEL9,
	FEEDBACK_PATTERN_LEVEL10,
	FEEDBACK_PATTERN_TIMER_ENDING,
	FEEDBACK_PATTERN_BURNER_DETECTED,
	FEEDBACK_PATTERN_BURNER_MOVED,
	FEEDBACK_PATTERN_CONNECTED,
	FEEDBACK_PATTERN_DISCONNECTED,
	FEEDBACK_PATTERN_WELCOME,
	FEEDBACK_PATTERN_AUTO_DOOR_OPEN,

	FEEDBACK_PATTERN_DA_END                 = 50000,
	FEEDBACK_PATTERN_INTERNAL_END           = 90000,
} feedback_pattern_internal_e;

/**
 * @}
 */

#ifdef __cplusplus
}
#endif

#endif //__FEEDBACK_IDS_INTERNAL_H__
