/*
 * libfeedback
 * Copyright (c) 2015 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <stdio.h>
#include <errno.h>
#include <stdlib.h>
#include <libsyscommon/ini-parser.h>

#include "feedback-config.h"
#include "profiles.h"
#include "log.h"

#define MAX_DATA	256

#define MATCH(a, b)             (!strncmp(a, b, strlen(a) + 1))
#define SET_CONF(a, b)          (a = (b > 0.0 ? b : a))

static int load_config_index = 0;

//LCOV_EXCL_START
static int load_config(struct parse_result *result, void *user_data)
{
	struct feedback_config_info *info = (struct feedback_config_info *)user_data;
	char *name;
	char *value;
	int pattern;

	if (!info)
		return -EINVAL;

	if (!MATCH(result->section, info->name))
		return -ENOENT;

	if (!result->name || !result->value)
		return -ENOENT;

	name = result->name;
	value = result->value;

	pattern = profile->get_pattern_enum(name);
	if (pattern < 0 || pattern >= profile->max_pattern)
		return -EINVAL;

	info->data[load_config_index].pattern = pattern;

	info->data[load_config_index].origin = strdup(value);
	if (!info->data[load_config_index].origin)
		_E("fail to copy %d sound data", //LCOV_EXCL_LINE
				pattern);
	load_config_index++;

	return 0;
}

int feedback_load_config(const char *path,
		struct feedback_config_info *info)
{
	int ret;
	int i;

	if (!path || !info)
		return -EINVAL;

	info->data = calloc(1,
			sizeof(struct feedback_data) * profile->get_num_of_pattern());
	if (!info->data) {
		_E("fail to allocate %s data", path); //LCOV_EXCL_LINE
		return -ENOMEM; //LCOV_EXCL_LINE System Error
	}

	for (i = 0; i < profile->get_num_of_pattern(); i++)
		info->data[i].pattern = -1;

	load_config_index = 0;
	ret = config_parse(path, load_config, info);
	if (ret < 0)
		_E("Failed to load %s, %d Use default value!", //LCOV_EXCL_LINE
				path, ret);

	return ret;
}

void feedback_free_config(struct feedback_config_info *info)
{
	int i;

	if (!info || !(info->data))
		return;

	if (!profile)
		return;

	for (i = 0; i < profile->get_num_of_pattern(); i++) {
		if (info->data[i].origin) {
			free(info->data[i].origin);
			info->data[i].origin = NULL;
		}
	}

	free(info->data);
	info->data = NULL;
	load_config_index = 0;
}
//LCOV_EXCL_STOP
