#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

#include "test.h"
#include "test-feedback-internal.h"

static int pass;
static int fail;

static int pattern_s[ARRAY_SIZE(test_pattern)] = { -1, };
static int pattern_i_s[ARRAY_SIZE(test_pattern_internal)] = { -1, };
static int pattern_v[ARRAY_SIZE(test_pattern)] = { -1, };
static int pattern_i_v[ARRAY_SIZE(test_pattern_internal)] = { -1, };

static void test_play_type_by_name_p()
{
	int i;
	char *name;
	bool s_end = false, v_end = false;

	feedback_initialize();

	for (i = 0; i < ARRAY_SIZE(test_pattern); i++)
	{
		if (pattern_s[i] == -1)	s_end = true;
		if (pattern_v[i] == -1) v_end = true;

		if (s_end && v_end) break;

		if (!s_end && (pattern_s[i] != -1)) {
			name = strdup(test_pattern[pattern_s[i]].name);
			RESULT(feedback_play_type_by_name("FEEDBACK_TYPE_SOUND", name), FEEDBACK_ERROR_NONE, name)
			free(name);
		}

		if (!v_end && (pattern_v[i] != -1)) {
			name = strdup(test_pattern[pattern_v[i]].name);
			RESULT(feedback_play_type_by_name("FEEDBACK_TYPE_VIBRATION", name), FEEDBACK_ERROR_NONE, name);
			free(name);
		}

		usleep(DELAY_TIME);
	}

	s_end = false;
	v_end = false;

	for (i = 0; i < ARRAY_SIZE(test_pattern_internal); i++)
	{
		if (pattern_i_s[i] == -1)	s_end = true;
		if (pattern_i_v[i] == -1)	v_end = true;

		if (s_end && v_end) break;

		if (!s_end && (pattern_i_s[i] != -1)) {
			name = strdup(test_pattern_internal[pattern_i_s[i]].name);
			RESULT(feedback_play_type_by_name("FEEDBACK_TYPE_SOUND", name), FEEDBACK_ERROR_NONE, name);
			free(name);
		}

		if (!v_end && (pattern_i_v[i] != -1)) {
			name = strdup(test_pattern_internal[pattern_i_v[i]].name);
			RESULT(feedback_play_type_by_name("FEEDBACK_TYPE_VIBRATION", name), FEEDBACK_ERROR_NONE, name);
			free(name);
		}

		usleep(DELAY_TIME);
	}

	feedback_deinitialize();
}

static void test_play_type_by_name_n()
{
	RESULT(feedback_play_type_by_name(NULL, "FEEDBACK_PATTERN_TAP"), FEEDBACK_ERROR_INVALID_PARAMETER, "type is null");

	RESULT(feedback_play_type_by_name("FEEDBACK_TYPE_VIBRATION", NULL), FEEDBACK_ERROR_INVALID_PARAMETER, "pattern is null");

	RESULT(feedback_play_type_by_name("INVALID_FEEDBACK_TYPE", "FEEDBACK_PATTERN_TAP"), FEEDBACK_ERROR_INVALID_PARAMETER, "invalid feedback type");

	RESULT(feedback_play_type_by_name("FEEDBACK_TYPE_SOUND", "INVALID_FEEDBACK_PATTERN"), FEEDBACK_ERROR_INVALID_PARAMETER, "invalid feedback pattern");
}

bool TEST_FEEDBACK_PLAY_TYPE_BY_NAME(void)
{
	INIT();

	test_play_type_by_name_p();
	test_play_type_by_name_n();

	REPORT_AND_RETURN();
}

static void test_play_internal_p()
{
	int i;

	feedback_initialize();

	for (i = 0; i < ARRAY_SIZE(test_pattern_internal); i++)
	{
		RESULT(feedback_play_internal(test_pattern_internal[i].pattern), FEEDBACK_ERROR_NONE, test_pattern_internal[i].name);
		usleep(DELAY_TIME);
	}

	feedback_deinitialize();
}

static void test_play_internal_n()
{
	RESULT(feedback_play_internal(FEEDBACK_PATTERN_TAP), FEEDBACK_ERROR_NOT_INITIALIZED, "not initialize");

	feedback_initialize();
	RESULT(feedback_play_internal(FEEDBACK_PATTERN_NONE), FEEDBACK_ERROR_INVALID_PARAMETER, "invalid pattern");
	feedback_deinitialize();
}

bool TEST_FEEDBACK_PLAY_INTERNAL(void)
{
	INIT();

	test_play_internal_p();
	test_play_internal_n();

	REPORT_AND_RETURN();
}

static void test_play_soundpath_internal_p()
{
	int i;
	struct _pattern_internal *pattern;

	feedback_initialize();

	for (i = 0; i < ARRAY_SIZE(test_pattern_internal); i++)
	{
		if (pattern_i_s[i] == -1)
			break;

		pattern = &test_pattern_internal[pattern_i_s[i]];
		if (pattern->path == NULL)
			continue;

		RESULT(feedback_play_soundpath_internal(pattern->pattern, pattern->path), FEEDBACK_ERROR_NONE, pattern->name);
		usleep(DELAY_TIME);
	}

	feedback_deinitialize();
}

static void test_play_soundpath_internal_n()
{
	RESULT(feedback_play_soundpath_internal(FEEDBACK_PATTERN_TAP, "/usr/share/feedback/sound/operation/operation.wav"), FEEDBACK_ERROR_NOT_INITIALIZED, "not initialize");

	feedback_initialize();

	RESULT(feedback_play_soundpath_internal(FEEDBACK_PATTERN_NONE, "/usr/share/feedback/sound/operation/operation.wav"), FEEDBACK_ERROR_INVALID_PARAMETER, "invalid pattern");
	RESULT(feedback_play_soundpath_internal(FEEDBACK_PATTERN_TAP, NULL), FEEDBACK_ERROR_INVALID_PARAMETER, "NULL sound path");

	feedback_deinitialize();
}

bool TEST_FEEDBACK_PLAY_SOUNDPATH_INTERNAL(void)
{
	INIT();

	test_play_soundpath_internal_p();
	test_play_soundpath_internal_n();

	REPORT_AND_RETURN();
}

static void test_play_type_internal_p()
{
	int i;
	bool s_end = false, v_end = false;

	feedback_initialize();

	for (i = 0; i < ARRAY_SIZE(test_pattern_internal); i++)
	{
		if (pattern_i_s[i] == -1) s_end = true;
		if (pattern_i_v[i] == -1) v_end = true;

		if (s_end && v_end)	break;

		if (!s_end && (pattern_i_s[i] != -1))
			RESULT(feedback_play_type_internal(FEEDBACK_TYPE_SOUND, test_pattern_internal[pattern_i_s[i]].pattern), FEEDBACK_ERROR_NONE, test_pattern_internal[pattern_i_s[i]].name);

		if (!v_end && (pattern_i_v[i] != -1))
			RESULT(feedback_play_type_internal(FEEDBACK_TYPE_VIBRATION, test_pattern_internal[pattern_i_v[i]].pattern), FEEDBACK_ERROR_NONE, test_pattern_internal[pattern_i_v[i]].name);

		usleep(DELAY_TIME);
	}

	feedback_deinitialize();
}

static void test_play_type_internal_n()
{
	RESULT(feedback_play_type_internal(FEEDBACK_TYPE_SOUND, FEEDBACK_PATTERN_TAP), FEEDBACK_ERROR_NOT_INITIALIZED, "not initialize");

	feedback_initialize();

	RESULT(feedback_play_type_internal(FEEDBACK_TYPE_NONE, FEEDBACK_PATTERN_TAP), FEEDBACK_ERROR_INVALID_PARAMETER, "invalid type");
	RESULT(feedback_play_type_internal(FEEDBACK_TYPE_VIBRATION, FEEDBACK_PATTERN_NONE), FEEDBACK_ERROR_INVALID_PARAMETER, "invalid pattern");

	feedback_deinitialize();
}

bool TEST_FEEDBACK_PLAY_TYPE_INTERNAL(void)
{
	INIT();

	test_play_type_internal_p();
	test_play_type_internal_n();

	REPORT_AND_RETURN();
}
static void test_play_type_soundpath_internal_p()
{
	int i;
	bool s_end = false, v_end = false;
	struct _pattern_internal *pattern;

	feedback_initialize();

    for (i = 0; i < ARRAY_SIZE(test_pattern_internal); i++)
    {
		if (pattern_i_s[i] == -1)	s_end = true;
		if (pattern_i_v[i] == -1)	v_end = true;

		if (s_end && v_end) break;

		if (!s_end && (pattern_i_s[i] != -1)) {
			pattern = &test_pattern_internal[pattern_i_s[i]];
        	if (pattern->path != NULL)
				RESULT(feedback_play_type_soundpath_internal(FEEDBACK_TYPE_SOUND, pattern->pattern, pattern->path), FEEDBACK_ERROR_NONE, pattern->name);
		}

		if (!v_end && (pattern_i_v[i] != -1)) {
			pattern = &test_pattern_internal[pattern_i_v[i]];
			RESULT(feedback_play_type_soundpath_internal(FEEDBACK_TYPE_VIBRATION, pattern->pattern, NULL), FEEDBACK_ERROR_NONE, pattern->name);
		}

        usleep(DELAY_TIME);
    }

	feedback_deinitialize();

}

static void test_play_type_soundpath_internal_n()
{
	RESULT(feedback_play_type_soundpath_internal(FEEDBACK_TYPE_SOUND, FEEDBACK_PATTERN_TAP, "/usr/share/feedback/sound/operation/operation.wav"), FEEDBACK_ERROR_NOT_INITIALIZED, "not initialize");

	feedback_initialize();

	RESULT(feedback_play_type_soundpath_internal(FEEDBACK_TYPE_NONE, FEEDBACK_PATTERN_TAP, "/usr/share/feedback/sound/operation/operation.wav"), FEEDBACK_ERROR_INVALID_PARAMETER, "invalid type");
	RESULT(feedback_play_type_soundpath_internal(FEEDBACK_TYPE_VIBRATION, FEEDBACK_PATTERN_NONE, "/usr/share/feedback/sound/operation/operation.wav"), FEEDBACK_ERROR_INVALID_PARAMETER, "invalid pattern");
	RESULT(feedback_play_type_soundpath_internal(FEEDBACK_TYPE_SOUND, FEEDBACK_PATTERN_TAP, NULL), FEEDBACK_ERROR_INVALID_PARAMETER, "invalid soundpath");

	feedback_deinitialize();
}

bool TEST_FEEDBACK_PLAY_TYPE_SOUNDPATH_INTERNAL(void)
{
	INIT();

	test_play_type_soundpath_internal_p();
	test_play_type_soundpath_internal_n();

	REPORT_AND_RETURN();
}

const char *feedback_play_sound_by_name(const char *pattern_name)
{
	int ret;

	feedback_initialize();
	ret = feedback_play_type_by_name("FEEDBACK_TYPE_SOUND", (char *)pattern_name);
    usleep(DELAY_TIME*10);
	feedback_deinitialize();

	return err_to_str(ret);
}

const char *feedback_play_vibration_by_name(const char *pattern_name)
{
	int ret;

	feedback_initialize();
	ret = feedback_play_type_by_name("FEEDBACK_TYPE_VIBRATION", (char *)pattern_name);
    usleep(DELAY_TIME*10);
	feedback_deinitialize();

	return err_to_str(ret);
}

void feedback_play_by_name(const char *pattern_name)
{
	feedback_play_sound_by_name(pattern_name);
	feedback_play_vibration_by_name(pattern_name);
}

static void init_supported_pattern(feedback_type_e type, int *pattern)
{
	int i, ret;
	int idx_supported = 0;
	bool status;

	feedback_initialize();

	for(i = 0; i < ARRAY_SIZE(test_pattern); i++) {
		ret = feedback_is_supported_pattern(type, test_pattern[i].pattern, &status);
		if ((ret == FEEDBACK_ERROR_NONE) && status)
			pattern[idx_supported++] = i;
	}
	pattern[idx_supported] = -1;

	feedback_deinitialize();
}

static void init_supported_pattern_i(feedback_type_e type, int *pattern_i)
{
	int i, ret;
	int idx_supported = 0;
	bool status;

	feedback_initialize();

	for(i = 0; i < ARRAY_SIZE(test_pattern_internal); i++) {
		ret = feedback_is_supported_pattern(type, test_pattern_internal[i].pattern, &status);
		if ((ret == FEEDBACK_ERROR_NONE) && status)
			pattern_i[idx_supported++] = i;
	}
	pattern_i[idx_supported] = -1;

	feedback_deinitialize();
}

static void test_get_count_of_sound_theme_internal(void)
{
	unsigned int count_of_theme = 0;

	RESULT(feedback_get_count_of_theme_internal(FEEDBACK_TYPE_SOUND, &count_of_theme),
		FEEDBACK_ERROR_NOT_INITIALIZED, "not initialized");

	feedback_initialize();
	RESULT(feedback_get_count_of_theme_internal(FEEDBACK_TYPE_SOUND, NULL),
		FEEDBACK_ERROR_INVALID_PARAMETER, "invalid parameter");
	RESULT(feedback_get_count_of_theme_internal(FEEDBACK_TYPE_VIBRATION, &count_of_theme),
		FEEDBACK_ERROR_NOT_SUPPORTED, "not supported");
	RESULT(feedback_get_count_of_theme_internal(FEEDBACK_TYPE_SOUND, &count_of_theme),
		FEEDBACK_ERROR_NONE, "error none");
	_D("Feedback type=%d count of theme=%d is get", FEEDBACK_TYPE_SOUND, count_of_theme);
	feedback_deinitialize();
}

bool TEST_FEEDBACK_GET_COUNT_OF_SOUND_THEME_INTERNAL(void)
{
	INIT();
	test_get_count_of_sound_theme_internal();
	REPORT_AND_RETURN();
}

static void test_get_sound_theme_id_internal(void)
{
	unsigned int id_of_theme = 0;

	feedback_initialize();
	RESULT(feedback_get_theme_id_internal(FEEDBACK_TYPE_SOUND, NULL),
		FEEDBACK_ERROR_INVALID_PARAMETER, "invalid parameter");
	RESULT(feedback_get_theme_id_internal(FEEDBACK_TYPE_VIBRATION, &id_of_theme),
		FEEDBACK_ERROR_NOT_SUPPORTED, "not supported");
	RESULT(feedback_get_theme_id_internal(FEEDBACK_TYPE_SOUND, &id_of_theme),
		FEEDBACK_ERROR_NONE, "error none");
	_D("Feedback type=%d sound theme id=%d is get", FEEDBACK_TYPE_SOUND, id_of_theme);
	feedback_deinitialize();
}

bool TEST_FEEDBACK_GET_SOUND_THEME_ID_INTERNAL(void)
{
	INIT();
	test_get_sound_theme_id_internal();
	REPORT_AND_RETURN();
}

static void test_set_sound_theme_id_internal(void)
{
	unsigned int id = 0;

	feedback_initialize();
	feedback_get_theme_id_internal(FEEDBACK_TYPE_SOUND, &id);

	RESULT(feedback_set_theme_id_internal(FEEDBACK_TYPE_SOUND, id),
		FEEDBACK_ERROR_NONE, "error none");

	RESULT(feedback_set_theme_id_internal(FEEDBACK_TYPE_VIBRATION, id),
		FEEDBACK_ERROR_NOT_SUPPORTED, "not supported");

	feedback_deinitialize();
}

bool TEST_FEEDBACK_SET_SOUND_THEME_ID_INTERNAL(void)
{
	INIT();
	test_set_sound_theme_id_internal();
	REPORT_AND_RETURN();
}

static void test_get_sound_theme_ids_internal(void)
{
	unsigned int count_of_theme = 0;
	unsigned int *sound_theme_ids = NULL;
	int index = 0;

	feedback_initialize();
	RESULT(feedback_get_theme_ids_internal(FEEDBACK_TYPE_VIBRATION, &count_of_theme, &sound_theme_ids),
		FEEDBACK_ERROR_NOT_SUPPORTED, "not supported");
	RESULT(feedback_get_theme_ids_internal(FEEDBACK_TYPE_SOUND, NULL, NULL),
		FEEDBACK_ERROR_INVALID_PARAMETER, "invalid parameter");

	feedback_get_theme_ids_internal(FEEDBACK_TYPE_SOUND, &count_of_theme, &sound_theme_ids);

	for (index = 0; index < count_of_theme; index++)
	{
		_D("Feedback type=Sound, sound theme id=%d is get", sound_theme_ids[index]);
		RESULT(feedback_set_theme_id_internal(FEEDBACK_TYPE_SOUND, sound_theme_ids[index]),
			FEEDBACK_ERROR_NONE, "error none");
	}

	feedback_deinitialize();
}

bool TEST_FEEDBACK_GET_SOUND_THEME_IDS_INTERNAL(void)
{
	INIT();
	test_get_sound_theme_ids_internal();
	REPORT_AND_RETURN();
}

static void test_put_sound_theme_ids_internal(void)
{
	unsigned int count_of_theme = 0;
	unsigned int *sound_theme_ids = NULL;

	feedback_initialize();
	RESULT(feedback_put_theme_ids_internal(&sound_theme_ids),
		FEEDBACK_ERROR_INVALID_PARAMETER, "invalid parameter");
	RESULT(feedback_put_theme_ids_internal(NULL),
		FEEDBACK_ERROR_INVALID_PARAMETER, "invalid parameter");

	feedback_get_theme_ids_internal(FEEDBACK_TYPE_SOUND, &count_of_theme, &sound_theme_ids);
	RESULT(feedback_put_theme_ids_internal(&sound_theme_ids),
		FEEDBACK_ERROR_NONE, "error none");
	feedback_deinitialize();
}

bool TEST_FEEDBACK_PUT_SOUND_THEME_IDS_INTERNAL(void)
{
	INIT();
	test_put_sound_theme_ids_internal();
	REPORT_AND_RETURN();
}

static void test_feedback_play_type_with_flags_internal(void)
{
	feedback_initialize();
	RESULT(feedback_play_type_with_flags_internal(FEEDBACK_TYPE_SOUND, FEEDBACK_PATTERN_TAP, -1), FEEDBACK_ERROR_INVALID_PARAMETER, "invalid parameter");
	RESULT(feedback_play_type_with_flags_internal(FEEDBACK_TYPE_VIBRATION, FEEDBACK_PATTERN_TAP, FEEDBACK_FLAG_PRIORITY_BASED_PLAY), FEEDBACK_ERROR_OPERATION_FAILED, "operation failed");
	RESULT(feedback_play_type_with_flags_internal(FEEDBACK_TYPE_SOUND, FEEDBACK_PATTERN_TAP, FEEDBACK_FLAG_PRIORITY_BASED_PLAY), FEEDBACK_ERROR_NONE, "error none");
	RESULT(feedback_play_type_with_flags_internal(FEEDBACK_TYPE_SOUND, FEEDBACK_PATTERN_TAP, FEEDBACK_FLAG_NONE), FEEDBACK_ERROR_NONE, "error none");
	feedback_deinitialize();
}

bool TEST_FEEDBACK_PLAY_TYPE_WITH_FLAGS_INTERNAL(void)
{
	INIT();
	test_feedback_play_type_with_flags_internal();
	REPORT_AND_RETURN();
}

void TEST_INTERNAL_INIT()
{
	init_supported_pattern(FEEDBACK_TYPE_SOUND, pattern_s);
	init_supported_pattern(FEEDBACK_TYPE_VIBRATION, pattern_v);
	init_supported_pattern_i(FEEDBACK_TYPE_SOUND, pattern_i_s);
	init_supported_pattern_i(FEEDBACK_TYPE_VIBRATION, pattern_i_v);
}
