/*
 * feedback-test
 * Copyright (c) 2020 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __TEST_FEEDBACK_INTERNAL_H__
#define __TEST_FEEDBACK_INTERNAL_H__

#include <stdio.h>
#include <stdbool.h>
#include <feedback-internal.h>

#ifdef __cplusplus
extern "C" {
#endif

static struct _pattern_internal {
	feedback_pattern_internal_e pattern;
	const char *name;
	const char *path;
} test_pattern_internal[] = {
	{ FEEDBACK_PATTERN_SIP_BACKSPACE,	"FEEDBACK_PATTERN_SIP_BACKSPACE",	NULL },
	{ FEEDBACK_PATTERN_SIP_FUNCTION,	"FEEDBACK_PATTERN_SIP_FUNCTION",	NULL },
	{ FEEDBACK_PATTERN_SIP_FJKEY,		"FEEDBACK_PATTERN_SIP_FJKEY",		NULL },
	{ FEEDBACK_PATTERN_MAX_CHARACTER,	"FEEDBACK_PATTERN_MAX_CHARACTER",	NULL },
	{ FEEDBACK_PATTERN_MULTI_TAP,		"FEEDBACK_PATTERN_MULTI_TAP",		NULL },
	{ FEEDBACK_PATTERN_MESSAGE_ON_CALL,	"FEEDBACK_PATTERN_MESSAGE_ON_CALL", NULL },
	{ FEEDBACK_PATTERN_EMAIL_ON_CALL,	"FEEDBACK_PATTERN_EMAIL_ON_CALL",	NULL },
	{ FEEDBACK_PATTERN_WAKEUP_ON_CALL,	"FEEDBACK_PATTERN_WAKEUP_ON_CALL",	NULL },
	{ FEEDBACK_PATTERN_SCHEDULE_ON_CALL,	"FEEDBACK_PATTERN_SCHEDULE_ON_CALL",	NULL },
	{ FEEDBACK_PATTERN_TIMER_ON_CALL,	"FEEDBACK_PATTERN_TIMER_ON_CALL",	NULL },
	{ FEEDBACK_PATTERN_GENERAL_ON_CALL,	"FEEDBACK_PATTERN_GENERAL_ON_CALL",	NULL },
	{ FEEDBACK_PATTERN_SMART_ALERT,		"FEEDBACK_PATTERN_SMART_ALERT",		NULL },
	{ FEEDBACK_PATTERN_CHARGERCONN_ON_CALL,	"FEEDBACK_PATTERN_CHARGERCONN_ON_CALL",	"/usr/share/feedback/sound/operation/operation.wav" },
	{ FEEDBACK_PATTERN_CHARGING_ERROR_ON_CALL,	"FEEDBACK_PATTERN_CHARGING_ERROR_ON_CALL",	NULL },
	{ FEEDBACK_PATTERN_FULLCHARGED_ON_CALL,	"FEEDBACK_PATTERN_FULLCHARGED_ON_CALL",	NULL },
	{ FEEDBACK_PATTERN_LOWBATT_ON_CALL,	"FEEDBACK_PATTERN_LOWBATT_ON_CALL",	"/usr/share/feedback/sound/operation/operation.wav" },
	{ FEEDBACK_PATTERN_LOCK_SWIPE,		"FEEDBACK_PATTERN_LOCK_SWIPE",		"/usr/share/feedback/sound/operation/operation.wav" },
	{ FEEDBACK_PATTERN_UNLOCK_SWIPE,	"FEEDBACK_PATTERN_UNLOCK_SWIPE",	"/usr/share/feedback/sound/operation/operation.wav" },
	{ FEEDBACK_PATTERN_GEOMETRIC_LOCK,	"FEEDBACK_PATTERN_GEOMETRIC_LOCK",	NULL },
	{ FEEDBACK_PATTERN_CALLCONNECT,		"FEEDBACK_PATTERN_CALLCONNECT",		NULL },
	{ FEEDBACK_PATTERN_DISCALLCONNECT,	"FEEDBACK_PATTERN_DISCALLCONNECT",	NULL },
	{ FEEDBACK_PATTERN_OUTGOING_CALL,	"FEEDBACK_PATTERN_OUTGOING_CALL",	NULL },
	{ FEEDBACK_PATTERN_MINUTEMINDER,	"FEEDBACK_PATTERN_MINUTEMINDER",	NULL },
	{ FEEDBACK_PATTERN_BT_PAIRING,		"FEEDBACK_PATTERN_BT_PAIRING",		NULL },
	{ FEEDBACK_PATTERN_BT_WAITING,		"FEEDBACK_PATTERN_BT_WAITING",		NULL },
	{ FEEDBACK_PATTERN_SCREEN_CAPTURE,	"FEEDBACK_PATTERN_SCREEN_CAPTURE",	"/usr/share/feedback/sound/operation/shutter.wav" },
	{ FEEDBACK_PATTERN_UV_PROCESSING,	"FEEDBACK_PATTERN_UV_PROCESSING",	NULL },
	{ FEEDBACK_PATTERN_SHEALTH_START,	"FEEDBACK_PATTERN_SHEALTH_START",	NULL },
	{ FEEDBACK_PATTERN_SHEALTH_PAUSE,	"FEEDBACK_PATTERN_SHEALTH_PAUSE",	NULL },
	{ FEEDBACK_PATTERN_SHEALTH_STOP,	"FEEDBACK_PATTERN_SHEALTH_STOP",	NULL },
	{ FEEDBACK_PATTERN_3RD_APPLICATION,	"FEEDBACK_PATTERN_3RD_APPLICATION",	NULL },
	{ FEEDBACK_PATTERN_TICK,			"FEEDBACK_PATTERN_TICK",			NULL },
	{ FEEDBACK_PATTERN_TRANSITION_CIRCULAR,	"FEEDBACK_PATTERN_TRANSITION_CIRCULAR",	NULL },
	{ FEEDBACK_PATTERN_TRANSITION_POP,	"FEEDBACK_PATTERN_TRANSITION_POP",	NULL },
	{ FEEDBACK_PATTERN_PROCESS,			"FEEDBACK_PATTERN_PROCESS",			NULL },
	{ FEEDBACK_PATTERN_MOVE_LIST,		"FEEDBACK_PATTERN_MOVE_LIST",		NULL },
	{ FEEDBACK_PATTERN_DISMISS,			"FEEDBACK_PATTERN_DISMISS",			NULL },
	{ FEEDBACK_PATTERN_CLOCK_SECOND_HAND,	"FEEDBACK_PATTERN_CLOCK_SECOND_HAND",	NULL },
	{ FEEDBACK_PATTERN_SPIRAL_DOWN,		"FEEDBACK_PATTERN_SPIRAL_DOWN",		NULL },
	{ FEEDBACK_PATTERN_MOVE_LIST_2,		"FEEDBACK_PATTERN_MOVE_LIST_2",		NULL },
	{ FEEDBACK_PATTERN_SPIRAL_UP,		"FEEDBACK_PATTERN_SPIRAL_UP",		NULL },
	{ FEEDBACK_PATTERN_SILENCE,			"FEEDBACK_PATTERN_SILENCE",			NULL },
	{ FEEDBACK_PATTERN_INACTIVE_TENSION,	"FEEDBACK_PATTERN_INACTIVE_TENSION",	NULL },
	{ FEEDBACK_PATTERN_INACTIVE_FINE,	"FEEDBACK_PATTERN_INACTIVE_FINE",	NULL },
	{ FEEDBACK_PATTERN_SHEALTH_NOTICE,	"FEEDBACK_PATTERN_SHEALTH_NOTICE",	NULL },
	{ FEEDBACK_PATTERN_SHEALTH_GENTLE_ALERT,	"FEEDBACK_PATTERN_SHEALTH_GENTLE_ALERT",	NULL },
	{ FEEDBACK_PATTERN_END_EFFECT_FINE,	"FEEDBACK_PATTERN_END_EFFECT_FINE",	NULL },
	{ FEEDBACK_PATTERN_CLICK_VALUE,		"FEEDBACK_PATTERN_CLICK_VALUE",		NULL },
	{ FEEDBACK_PATTERN_CLICK_FINE_TRAIN_1,	"FEEDBACK_PATTERN_CLICK_FINE_TRAIN_1",	NULL },
	{ FEEDBACK_PATTERN_CLICK_FINE,		"FEEDBACK_PATTERN_CLICK_FINE",		NULL },
	{ FEEDBACK_PATTERN_CLICK_SLIDER,	"FEEDBACK_PATTERN_CLICK_SLIDER",	NULL },
	{ FEEDBACK_PATTERN_CLICK_MEDIUM,	"FEEDBACK_PATTERN_CLICK_MEDIUM",	NULL },
	{ FEEDBACK_PATTERN_CLICK_STRONG,	"FEEDBACK_PATTERN_CLICK_STRONG",	NULL },
	{ FEEDBACK_PATTERN_TURN_RIGHT,		"FEEDBACK_PATTERN_TURN_RIGHT",		NULL },
	{ FEEDBACK_PATTERN_TURN_LEFT,		"FEEDBACK_PATTERN_TURN_LEFT",		NULL },
	{ FEEDBACK_PATTERN_FUNCTION,		"FEEDBACK_PATTERN_FUNCTION",		NULL },
	{ FEEDBACK_PATTERN_VOICE_START,		"FEEDBACK_PATTERN_VOICE_START",		NULL },
	{ FEEDBACK_PATTERN_VOICE_STOP,		"FEEDBACK_PATTERN_VOICE_STOP",		NULL },
	{ FEEDBACK_PATTERN_COMMUNICATION,	"FEEDBACK_PATTERN_COMMUNICATION",	NULL },
	{ FEEDBACK_PATTERN_HEARTBEAT,		"FEEDBACK_PATTERN_HEARTBEAT",		NULL },
	{ FEEDBACK_PATTERN_HEARTBEAT_FAST,	"FEEDBACK_PATTERN_HEARTBEAT_FAST",	NULL },
	{ FEEDBACK_PATTERN_SETTING_ON,		"FEEDBACK_PATTERN_SETTING_ON",		NULL },
	{ FEEDBACK_PATTERN_SETTING_OFF,		"FEEDBACK_PATTERN_SETTING_OFF",		NULL },
	{ FEEDBACK_PATTERN_CONNECT,			"FEEDBACK_PATTERN_CONNECT",			NULL },
	{ FEEDBACK_PATTERN_DISCONNECT,		"FEEDBACK_PATTERN_DISCONNECT",		NULL },
	{ FEEDBACK_PATTERN_HOURLY_ALERT,	"FEEDBACK_PATTERN_HOURLY_ALERT",	NULL },
	{ FEEDBACK_PATTERN_SAFETY_ALERT,	"FEEDBACK_PATTERN_SAFETY_ALERT",	NULL },
	{ FEEDBACK_PATTERN_ACCIDENT_DETECT, "FEEDBACK_PATTERN_ACCIDENT_DETECT", NULL },
	{ FEEDBACK_PATTERN_SEND_SOS_MESSAGE,	"FEEDBACK_PATTERN_SEND_SOS_MESSAGE",	NULL },
	{ FEEDBACK_PATTERN_END_SOS_MESSAGE,	"FEEDBACK_PATTERN_END_SOS_MESSAGE",	NULL },
	{ FEEDBACK_PATTERN_EMERGENCY_BUZZER,	"FEEDBACK_PATTERN_EMERGENCY_BUZZER",	NULL },
	{ FEEDBACK_PATTERN_SAFETY_LOW_POWER,	"FEEDBACK_PATTERN_SAFETY_LOW_POWER",	NULL },
	{ FEEDBACK_PATTERN_CMAS,			"FEEDBACK_PATTERN_CMAS",			NULL },
	{ FEEDBACK_PATTERN_RINGER,			"FEEDBACK_PATTERN_RINGER",			NULL },
	{ FEEDBACK_PATTERN_NOTIFICATION,	"FEEDBACK_PATTERN_NOTIFICATION",	NULL },
	{ FEEDBACK_PATTERN_INFO,			"FEEDBACK_PATTERN_INFO",			NULL },
	{ FEEDBACK_PATTERN_WARNING,			"FEEDBACK_PATTERN_WARNING",			NULL },
	{ FEEDBACK_PATTERN_ERROR,			"FEEDBACK_PATTERN_ERROR",			NULL },
	{ FEEDBACK_PATTERN_EMERGENCY,		"FEEDBACK_PATTERN_EMERGENCY",		NULL },
	{ FEEDBACK_PATTERN_INTERNAL_WAKEUP,	"FEEDBACK_PATTERN_INTERNAL_WAKEUP",	NULL },
	{ FEEDBACK_PATTERN_INTERNAL_TIMER,	"FEEDBACK_PATTERN_INTERNAL_TIMER",	NULL },
	{ FEEDBACK_PATTERN_TEMPERATURE_WARNING,	"FEEDBACK_PATTERN_TEMPERATURE_WARNING",	NULL },
};

bool TEST_FEEDBACK_PLAY_TYPE_BY_NAME(void);
bool TEST_FEEDBACK_PLAY_INTERNAL(void);
bool TEST_FEEDBACK_PLAY_SOUNDPATH_INTERNAL(void);
bool TEST_FEEDBACK_PLAY_TYPE_INTERNAL(void);
bool TEST_FEEDBACK_PLAY_TYPE_SOUNDPATH_INTERNAL(void);
bool TEST_FEEDBACK_GET_COUNT_OF_SOUND_THEME_INTERNAL(void);
bool TEST_FEEDBACK_GET_SOUND_THEME_ID_INTERNAL(void);
bool TEST_FEEDBACK_SET_SOUND_THEME_ID_INTERNAL(void);
bool TEST_FEEDBACK_GET_SOUND_THEME_IDS_INTERNAL(void);
bool TEST_FEEDBACK_PUT_SOUND_THEME_IDS_INTERNAL(void);
bool TEST_FEEDBACK_PLAY_TYPE_WITH_FLAGS_INTERNAL(void);

void TEST_INTERNAL_INIT(void);

void feedback_play_by_name(const char *pattern_name);
const char *feedback_play_sound_by_name(const char *pattern_name);
const char * feedback_play_vibration_by_name(const char *pattern_name);

/**
 * @}
 */


#ifdef __cplusplus
}
#endif

#endif //__TEST_FEEDBACK_INTERNAL_H__
