#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

#include "test.h"
#include "test-feedback.h"

static int pass;
static int fail;

static void test_initialize_p(void)
{
	RESULT(feedback_initialize(), FEEDBACK_ERROR_NONE, "nomal test");
	RESULT(feedback_initialize(), FEEDBACK_ERROR_NONE, "2nd test"); // checking multi initialize

	feedback_deinitialize();
	feedback_deinitialize();
}

bool TEST_FEEDBACK_INITIALIZE(void)
{
	INIT();
	test_initialize_p();
	REPORT_AND_RETURN();
}

static void test_deinitialize_p(void)
{
	feedback_initialize();
	feedback_initialize();

	RESULT(feedback_deinitialize(), FEEDBACK_ERROR_NONE, "normal test");
	RESULT(feedback_deinitialize(), FEEDBACK_ERROR_NONE, "2nd test");
}

static void test_deinitialize_n(void)
{
	RESULT(feedback_deinitialize(), FEEDBACK_ERROR_NOT_INITIALIZED, "without init");

	feedback_initialize();
	feedback_deinitialize();
	RESULT(feedback_deinitialize(), FEEDBACK_ERROR_NOT_INITIALIZED, "duplicated");
}

bool TEST_FEEDBACK_DEINITIALIZE(void)
{
	INIT();
	test_deinitialize_p();
	test_deinitialize_n();
	REPORT_AND_RETURN();
}

static void test_is_supported_pattern_p(void)
{
	int type, j;
	bool status;

	feedback_initialize();
	for (type = FEEDBACK_TYPE_NONE+1; type < FEEDBACK_TYPE_END; type++) {
		for (j = 0; j < ARRAY_SIZE(test_pattern); j++) {
			RESULT(feedback_is_supported_pattern(type, test_pattern[j].pattern, &status),
				FEEDBACK_ERROR_NONE, test_pattern[j].name);
		}
	}
	feedback_deinitialize();
}

static void test_is_supported_pattern_n(void)
{
	bool status;

	RESULT(feedback_is_supported_pattern(FEEDBACK_TYPE_SOUND, test_pattern[0].pattern, &status),
				FEEDBACK_ERROR_NOT_INITIALIZED, "without init");

	feedback_initialize();
	RESULT(feedback_is_supported_pattern(FEEDBACK_TYPE_NONE, test_pattern[0].pattern, &status),
				FEEDBACK_ERROR_INVALID_PARAMETER, "type none");
	RESULT(feedback_is_supported_pattern(FEEDBACK_TYPE_END, test_pattern[0].pattern, &status),
				FEEDBACK_ERROR_INVALID_PARAMETER, "type end");
	RESULT(feedback_is_supported_pattern(FEEDBACK_TYPE_SOUND, test_pattern[0].pattern, NULL),
				FEEDBACK_ERROR_INVALID_PARAMETER, "status NULL");
	RESULT(feedback_is_supported_pattern(FEEDBACK_TYPE_SOUND, FEEDBACK_PATTERN_NONE, &status),
				FEEDBACK_ERROR_INVALID_PARAMETER, "pattern NULL");
	//RESULT(feedback_is_supported_pattern(FEEDBACK_TYPE_SOUND, FEEDBACK_PATTERN_END, &status),
	//			FEEDBACK_ERROR_INVALID_PARAMETER, "pattern end");
	feedback_deinitialize();
}

bool TEST_FEEDBACK_IS_SUPPORTED_PATTERN(void)
{
	INIT();
	test_is_supported_pattern_p();
	test_is_supported_pattern_n();
	REPORT_AND_RETURN();
}

static void test_play_p(void)
{
	int i;

	feedback_initialize();
	for (i = 0; i < ARRAY_SIZE(test_pattern); ++i) {
		RESULT(feedback_play(test_pattern[i].pattern), FEEDBACK_ERROR_NONE, test_pattern[i].name);
		usleep(DELAY_TIME);
	}
	feedback_deinitialize();
}

static void test_play_n(void)
{
	RESULT(feedback_play(FEEDBACK_PATTERN_TAP), FEEDBACK_ERROR_NOT_INITIALIZED, "without init");

	feedback_initialize();
	RESULT(feedback_play(FEEDBACK_PATTERN_NONE), FEEDBACK_ERROR_INVALID_PARAMETER, "pattern NULL");
	feedback_deinitialize();
}

bool TEST_FEEDBACK_PLAY(void)
{
	INIT();
	test_play_p();
	test_play_n();
	REPORT_AND_RETURN();
}

static void INIT_PATTERN_LIST(feedback_type_e type, int *supported, int *nsupported, int *not_supported, int *n_not_supported)
{
    int idx_supported = 0, idx_not_supported = 0;
    int i;
    bool status;

    if (!supported || !not_supported)
        return;

    memset(supported, -1, ARRAY_SIZE(test_pattern) * sizeof(int));
    memset(not_supported, -1, ARRAY_SIZE(test_pattern) * sizeof(int));

    feedback_initialize();

    for (i = 0; i < ARRAY_SIZE(test_pattern); ++i) {
        feedback_is_supported_pattern(type, test_pattern[i].pattern, &status);
        if (status)
            supported[idx_supported++] = i;
        else
            not_supported[idx_not_supported++] = i;
    }
    feedback_deinitialize();

	if (nsupported)	*nsupported = idx_supported;
	if (n_not_supported) *n_not_supported = idx_not_supported;
}

static void test_play_type_p(feedback_type_e type, int *supported, int ncount)
{
	int i;

	if (!supported)
		return ;

	feedback_initialize();
	for (i = 0; i < ncount; i++) {
		RESULT(feedback_play_type(type, test_pattern[(feedback_pattern_e)supported[i]].pattern),
			FEEDBACK_ERROR_NONE, test_pattern[(feedback_pattern_e)supported[i]].name);
	}
	feedback_deinitialize();
}

static void test_play_type_n(feedback_type_e type, int *notsupported, int ncount)
{
	int i;

	if (!notsupported)
		return ;

	RESULT(feedback_play_type(type, FEEDBACK_PATTERN_TAP), FEEDBACK_ERROR_NOT_INITIALIZED, "without init");

	feedback_initialize();
	for (i = 0; i < ncount; i++) {
		RESULT(feedback_play_type(type, test_pattern[(feedback_pattern_e)notsupported[i]].pattern),
			FEEDBACK_ERROR_NOT_SUPPORTED, test_pattern[(feedback_pattern_e)notsupported[i]].name);
	}
	feedback_deinitialize();
}

bool TEST_FEEDBACK_PLAY_TYPE(void)
{
	int type;
	int nSupported = 0, nNotSupported = 0;
	int *pSupported = malloc(ARRAY_SIZE(test_pattern)*sizeof(int));
	int *pNotSupported = malloc(ARRAY_SIZE(test_pattern)*sizeof(int));

	INIT();

	for (type = FEEDBACK_TYPE_NONE+1; type < FEEDBACK_TYPE_END; type++) {
		INIT_PATTERN_LIST(type, pSupported, &nSupported, pNotSupported, &nNotSupported);
		test_play_type_p(type, pSupported, nSupported);
		if (type != FEEDBACK_TYPE_VIBRATION)
			test_play_type_n(type, pNotSupported, nNotSupported);
	}

	free(pSupported);
	free(pNotSupported);

	REPORT_AND_RETURN();
}

static void test_stop_p()
{
	feedback_initialize();
	RESULT(feedback_stop(), FEEDBACK_ERROR_NONE, "normal test");
	feedback_deinitialize();
}

static void test_stop_n()
{
	RESULT(feedback_stop(), FEEDBACK_ERROR_NOT_INITIALIZED, "without init");
}

bool TEST_FEEDBACK_STOP(void)
{
	INIT();
	test_stop_p();
	test_stop_n();
	REPORT_AND_RETURN();
}
